<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:output method="html" doctype-public="-//W3C//DTD HTML 4.0//EN"/>

<xsl:template match="/">
  <!-- contents: standard -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="standard">
  <!-- contents: @language tpage body -->
  <html>
    <head>
      <title>ISO/IEC IT --- Simple Test ---</title>
    </head>
    <style>
      h1    { font-size: 24pt ;
          color : white ;
          background-color: blue ;}
      h2    { font-soze: 24pt ;
          color : white ;
          background-color: green ;}
      h3    { font-size: 12pt ;
          color : black ;
          background-color: white ;}
      h4    { font-size: 10pt ;
          color : black ;
          background-color: white ;}
      h5    { font-size: 10pt ;
          color : black ;
          background-color: white ;}
      h6    { font-size: 10pt ;
          color : black ;
          background-color: white ;}
      strong.blue  { color: blue ;
          font-weight: bold ;}
      dt    { font-weight: bold ;}
      ol    { list-style: none outside }
      ul    { list-style: none outside }
      a:link    { color: blue ;}
      a:visit    { text-decoration: line-through ;}
      a:active  { color: red ;}
      a:hover    { color: white ;}
      p    { margin-top : 0.5em ;
          margin-bottom : 1.5em ;}
      item    { color: blue ;
          font-weight: bold ;}
      fn    { color: blue ;
          font-weight: bold ;}
    </style>
    <body>
      <xsl:call-template name="index"/>
      <xsl:apply-templates/>
    </body>
  </html>
</xsl:template>

<xsl:template name="index">
  <h1>Index</h1>
  <ul>
    <xsl:for-each select="foreword|body/scope|body/refs|body/defs|//h1|//h2|//h3|//h4|//h5|//h6|//p2|//p3|//p4|//p5|//p6|annexi">
      <xsl:call-template name="index-one"/>
    </xsl:for-each>
  </ul>
  <hr/>
</xsl:template>

<xsl:template name="index-one">
  <li>
    <xsl:element name="a">
      <xsl:choose>
        <xsl:when test='self::foreword'>
          <xsl:attribute name="href">
            <xsl:text>#fo</xsl:text>
            <xsl:number level="any" count="foreword"/>
          </xsl:attribute>
        </xsl:when>
        <xsl:when test='ancestor::body'>
          <xsl:attribute name="href">
            <xsl:text>#bo</xsl:text>
            <xsl:number level="multiple" count="scope|refs|defs|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" from="body"/>
          </xsl:attribute>
          <xsl:number level="multiple" count="scope|refs|defs|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" from="body" format="1.1 "/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="href">
            <xsl:text>#an</xsl:text>
            <xsl:number level="multiple" count="annexi|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6"/>
          </xsl:attribute>
          <xsl:number level="multiple" count="annexi|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" format="A.1 "/>
        </xsl:otherwise>
      </xsl:choose>
      <xsl:value-of select="ht"/>
    </xsl:element>
  </li>
</xsl:template>

<xsl:template match="tpage">
  <!-- contents: text() -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="foreword">
  <!-- contents: ht p -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="foreword/ht">
  <!-- contents: text() -->
  <h1>
    <xsl:element name="a">
      <xsl:attribute name="name">
        <xsl:text>fo</xsl:text>
        <xsl:number level="any" count="foreword"/>
      </xsl:attribute>
      <xsl:value-of select="."/>
    </xsl:element>
  </h1>
</xsl:template>

<xsl:template match="p">
  <!-- contents: text() -->
  <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="body">
  <!-- contents: scope refs defs h1 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="scope">
  <!-- contents: ht p -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="refs">
  <!-- contents: ht p -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="defs">
  <!-- contents: ht p tl -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="scope/ht|refs/ht|defs/ht">
  <!-- contents: text() -->
  <h1>
    <xsl:call-template name="anchor-text"/>
  </h1>
</xsl:template>

<xsl:template name="anchor-text">
  <xsl:element name="a">
    <xsl:choose>
      <xsl:when test='ancestor::body'>
        <xsl:attribute name="name">
          <xsl:text>bo</xsl:text>
          <xsl:number level="multiple" count="scope|refs|defs|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" from="body"/>
        </xsl:attribute>
        <xsl:number level="multiple" count="scope|refs|defs|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" from="body" format="1.1 "/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="name">
          <xsl:text>an</xsl:text>
          <xsl:number level="multiple" count="annexi|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6"/>
        </xsl:attribute>
        <xsl:number level="multiple" count="annexi|h1|h2|h3|h4|h5|h6|p2|p3|p4|p5|p6" format="A.1 "/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:if test='self::ht'>
      <xsl:value-of select="."/>
    </xsl:if>
  </xsl:element>
</xsl:template>

<xsl:template match="tl">
  <!-- contents: c1* cc1* -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="c1">
  <!-- contents: @gtext termdef termdes note p c2 -->
  <dl>
    <xsl:apply-templates/>
  </dl>
</xsl:template>

<xsl:template match="termdef">
  <!-- contents: text() -->
  <dt><xsl:value-of select="../@gtext"/><xsl:text> </xsl:text>
    <xsl:apply-templates/></dt>
</xsl:template>

<xsl:template match="termdes">
  <!-- contents: text() -->
  <dd><xsl:apply-templates/></dd>
</xsl:template>

<xsl:template match="note">
  <!-- contents: text() -->
  <p><xsl:text>NOTE </xsl:text>
    <xsl:number level="any" count="note" from="body" format="1 "/>
    <xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="c2">
  <!-- contents: @gtext termdef termdes note p -->
  <dl>
    <xsl:apply-templates/>
  </dl>
</xsl:template>

<xsl:template match="cc1">
  <!-- contents: @gtext hc c2* -->
  <dl>
    <xsl:apply-templates/>
  </dl>
</xsl:template>

<xsl:template match="hc">
  <!-- contents: text() -->
  <dt><xsl:value-of select="../@gtext"/><xsl:text> </xsl:text>
    <xsl:apply-templates/></dt>
</xsl:template>

<xsl:template match="fn">
  <!-- contents: text() -->
  <xsl:text> (</xsl:text><xsl:apply-templates/><xsl:text>)</xsl:text>
</xsl:template>

<xsl:template match="h1">
  <!-- contents: ht h2 p2 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body/h1/ht">
  <!-- contents: text() -->
  <h1>
    <xsl:call-template name="anchor-text"/>
  </h1>
</xsl:template>

<xsl:template match="h2">
  <!-- contents: ht p note h3 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body//h2/ht">
  <!-- contents: text() -->
  <h2>
    <xsl:call-template name="anchor-text"/>
  </h2>
</xsl:template>

<xsl:template match="h3">
  <!-- contents: ht p note h4 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body//h3/ht">
  <!-- contents: text() -->
  <h3>
    <xsl:call-template name="anchor-text"/>
  </h3>
</xsl:template>

<xsl:template match="h4">
  <!-- contents: ht p note h5 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body//h4/ht">
  <!-- contents: text() -->
  <h4>
    <xsl:call-template name="anchor-text"/>
  </h4>
</xsl:template>

<xsl:template match="h5">
  <!-- contents: ht p note h6 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body//h5/ht">
  <!-- contents: text() -->
  <h5>
    <xsl:call-template name="anchor-text"/>
  </h5>
</xsl:template>

<xsl:template match="h6">
  <!-- contents: ht p note -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="body//h6/ht">
  <!-- contents: text() -->
  <h6>
    <xsl:call-template name="anchor-text"/>
  </h6>
</xsl:template>

<xsl:template match="p2">
  <!-- contents: p note p3 -->
  <h2>
    <xsl:call-template name="anchor-text"/>
  </h2>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="p3">
  <!-- contents: p note p4 -->
  <h3>
    <xsl:call-template name="anchor-text"/>
  </h3>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="p4">
  <!-- contents: p note p5 -->
  <h4>
    <xsl:call-template name="anchor-text"/>
  </h4>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="p5">
  <!-- contents: p note p6 -->
  <h5>
    <xsl:call-template name="anchor-text"/>
  </h5>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="p6">
  <!-- contents: p note -->
  <h6>
    <xsl:call-template name="anchor-text"/>
  </h6>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="ul">
  <!-- contents: @format[NULL bullet emdash sl] li ul -->
  <ul><xsl:apply-templates/></ul>
</xsl:template>

<xsl:template match="ol">
  <!-- contents: @format[NULL alpha arabic roman arabicn] li ol -->
  <ol><xsl:apply-templates/></ol>
</xsl:template>

<xsl:template match="ul/li">
  <!-- contents: -->
  <xsl:variable name="format" select="../@format"/>
  <xsl:choose>
    <xsl:when test='$format="bullet"'>
      <li>&#183; <xsl:apply-templates/></li>
    </xsl:when>
    <xsl:when test='$format="emdash"'>
      <li>- <xsl:apply-templates/></li>
    </xsl:when>
    <xsl:when test='$format="sl"'>
      <li><xsl:apply-templates/></li>
    </xsl:when>
    <xsl:otherwise>
      <xsl:variable name="level" select="count(ancestor::ul)"/>
      <xsl:choose>
        <xsl:when test='$level=2'>
          <li>&#183; <xsl:apply-templates/></li>
        </xsl:when>
        <xsl:otherwise>
          <li>- <xsl:apply-templates/></li>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="ol/li">
  <!-- contents: -->
  <xsl:variable name="format" select="../@format"/>
  <xsl:choose>
    <xsl:when test='$format="alpha"'>
      <li><xsl:number format="a) "/><xsl:apply-templates/></li>
    </xsl:when>
    <xsl:when test='$format="arabic"'>
      <li><xsl:number format="1) "/><xsl:apply-templates/></li>
    </xsl:when>
    <xsl:when test='$format="roman"'>
      <li><xsl:number format="i) "/><xsl:apply-templates/></li>
    </xsl:when>
    <xsl:otherwise>
      <xsl:variable name="level" select="count(ancestor::ol) mod 3"/>
      <xsl:choose>
        <xsl:when test='$level=1'>
          <li><xsl:number format="a) "/><xsl:apply-templates/></li>
        </xsl:when>
        <xsl:when test='$level=2'>
          <li><xsl:number format="1) "/><xsl:apply-templates/></li>
        </xsl:when>
        <xsl:otherwise>
          <li><xsl:number format="i) "/><xsl:apply-templates/></li>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="dl">
  <!-- contents: @format[NULL ul ol syml varl] dlentry -->
  <xsl:choose>
    <xsl:when test='@format="ul"'>
      <ul><xsl:apply-templates/></ul>
    </xsl:when>
    <xsl:when test='@format="ol"'>
      <ol><xsl:apply-templates/></ol>
    </xsl:when>
    <xsl:otherwise>
      <dl><xsl:apply-templates/></dl>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="dlentry">
  <!-- contents: dt dd -->
  <xsl:variable name="format" select="../@format"/>
  <xsl:choose>
    <xsl:when test='$format="ul"'>
      <li><xsl:value-of select="dt"/><xsl:text> </xsl:text>
        <xsl:value-of select="dd"/></li>
    </xsl:when>
    <xsl:when test='$format="ol"'>
      <li><xsl:value-of select="dt"/><xsl:text> </xsl:text>
        <xsl:value-of select="dd"/></li>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="dt">
  <!-- contents: text() -->
  <dt><xsl:apply-templates/></dt>
</xsl:template>

<xsl:template match="dd">
  <!-- contents: text() -->
  <dd><xsl:apply-templates/></dd>
</xsl:template>

<xsl:template match="hp">
  <!-- contents: @format[none bold italic boldit uline oline code hide ] text() -->
  <xsl:choose>
    <xsl:when test='@format="bold"'>
      <b><xsl:apply-templates/></b>
    </xsl:when>
    <xsl:when test='@format="italic"'>
      <i><xsl:apply-templates/></i>
    </xsl:when>
    <xsl:when test='@format="boldit"'>
      <i><b><xsl:apply-templates/></b></i>
    </xsl:when>
    <xsl:when test='@format="uline"'>
      <u><xsl:apply-templates/></u>
    </xsl:when>
    <xsl:when test='@format="oline"'>
      <s><xsl:apply-templates/></s>
    </xsl:when>
    <xsl:when test='@format="code"'>
      <code><xsl:apply-templates/></code>
    </xsl:when>
    <xsl:when test='@format="hide"'>
      <del><xsl:apply-templates/></del>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="superscript">
  <!-- contents: text() -->
  <sup><xsl:apply-templates/></sup>
</xsl:template>

<xsl:template match="subscript">
  <!-- contents: text() -->
  <sub><xsl:apply-templates/></sub>
</xsl:template>

<xsl:template match="annexi">
  <!-- contents: ht h1 -->
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="annexi/ht">
  <!-- contents: text() -->
  <h1>
    <xsl:call-template name="anchor-text"/>
  </h1>
</xsl:template>

<xsl:template match="annexi/h1/ht">
  <!-- contents: text() -->
  <h2>
    <xsl:call-template name="anchor-text"/>
  </h2>
</xsl:template>

<xsl:template match="annexi//h2/ht">
  <!-- contents: text() -->
  <h3>
    <xsl:call-template name="anchor-text"/>
  </h3>
</xsl:template>

<xsl:template match="annexi//h3/ht">
  <!-- contents: text() -->
  <h4>
    <xsl:call-template name="anchor-text"/>
  </h4>
</xsl:template>

<xsl:template match="annexi//h4/ht">
  <!-- contents: text() -->
  <h5>
    <xsl:call-template name="anchor-text"/>
  </h5>
</xsl:template>

<xsl:template match="annexi//h5/ht">
  <!-- contents: text() -->
  <h6>
    <xsl:call-template name="anchor-text"/>
  </h6>
</xsl:template>

<xsl:template match="annexi//h6/ht">
  <!-- contents: text() -->
  <p>
    <xsl:call-template name="anchor-text"/>
  </p>
</xsl:template>

<xsl:template match="annexi//p2">
  <!-- contents: p note p3 -->
  <h3>
    <xsl:call-template name="anchor-text"/>
  </h3>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="annexi//p3">
  <!-- contents: p note p4 -->
  <h4>
    <xsl:call-template name="anchor-text"/>
  </h4>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="annexi//p4">
  <!-- contents: p note p5 -->
  <h5>
    <xsl:call-template name="anchor-text"/>
  </h5>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="annexi//p5">
  <!-- contents: p note p6 -->
  <h6>
    <xsl:call-template name="anchor-text"/>
  </h6>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="annexi//p6">
  <!-- contents: p note -->
  <p>
    <xsl:call-template name="anchor-text"/>
  </p>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="table">
  <table>
    <xsl:choose>
      <xsl:when test='@frame="none"'/>
      <xsl:otherwise>
        <xsl:attribute name="border"/>
      </xsl:otherwise>      
    </xsl:choose>
    <xsl:apply-templates/>
  </table>
</xsl:template>

<xsl:template match="tabtitle">
  <caption><xsl:apply-templates/></caption>
</xsl:template>

<xsl:template match="tgroup">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="colspec">
</xsl:template>

<xsl:template match="thead">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tbody">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="tfoot">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="row">
  <tr>
    <xsl:choose>
      <xsl:when test='parent::thead or parent::tfoot'>
        <xsl:attribute name="bgcolor">#d0d0d0</xsl:attribute>
      </xsl:when>
    </xsl:choose>
    <xsl:choose>
      <xsl:when test='@valign'>
        <xsl:attribute name="valign">
          <xsl:value-of select="@valign"/>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test='parent::*[@valign]'>
        <xsl:attribute name="valign">
          <xsl:value-of select="parent::*[@valign]"/>
        </xsl:attribute>
      </xsl:when>
      <xsl:when test='parent::thead'>
        <xsl:attribute name="valign">bottom</xsl:attribute>
      </xsl:when>
      <xsl:otherwise>
        <xsl:attribute name="valign">top</xsl:attribute>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates/>
  </tr>
</xsl:template>

<xsl:template match="entry">
  <xsl:choose>
    <xsl:when test='ancestor::thead'>
      <xsl:call-template name="ent">
        <xsl:with-param name="tag">th</xsl:with-param>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="ent">
        <xsl:with-param name="tag">td</xsl:with-param>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="ent">
  <xsl:element name="{$tag}">
    <xsl:if test='@valign'>
      <xsl:attribute name="valign">
        <xsl:value-of select="@valign"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test='@align'>
      <xsl:attribute name="align">
        <xsl:value-of select="@align"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test='@morerows'>
      <xsl:attribute name="rowspan">
        <xsl:value-of select="@morerows + 1"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test='@namest and @nameend'>
      <xsl:call-template name="colspan">
        <xsl:with-param name="namest">
          <xsl:value-of select="@namest"/>
        </xsl:with-param>
        <xsl:with-param name="nameend">
          <xsl:value-of select="@nameend"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template name="colspan">
  <xsl:call-template name="colspan-sub">
    <xsl:with-param name="numst">
      <xsl:choose>
        <xsl:when test='parent::row/preceding-sibling::colspec[@colname=$namest]'>
          <xsl:value-of select="count(parent::row/preceding-sibling::colspec[@colname=$namest]/preceding-sibling::colspec)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="count(ancestor::tgroup/child::colspec[@colname=$namest]/preceding-sibling::colspec)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:with-param>
    <xsl:with-param name="numend">
      <xsl:choose>
        <xsl:when test='parent::row/preceding-sibling::colspec[@colname=$nameend]'>
          <xsl:value-of select="count(parent::row/preceding-sibling::colspec[@colname=$nameend]/preceding-sibling::colspec)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="count(ancestor::tgroup/child::colspec[@colname=$nameend]/preceding-sibling::colspec)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template name="colspan-sub">
  <xsl:attribute name="colspan">
    <xsl:value-of select="$numend - $numst + 1"/>
  </xsl:attribute>
</xsl:template>

</xsl:stylesheet>
